From 0b388a3b77098421bbfe6d5494d265acfb90be35 Mon Sep 17 00:00:00 2001
From: Janusz Krzysztofik <jkrzyszt@tis.icnet.pl>
Date: Fri, 8 Jul 2011 01:46:30 +0200
Subject: [PATCH] Fix 'Poll received unknown value' wrong byte count

If it ever happens that a broken sequence, other than an incoming
powerline signal, is fetched from the Heyu spool file by the engine or
monitor, the check4poll() function puts all 0xff bytes collected so far
back to the buffer and passes them, together with the following byte,
for being reported with the "Poll received unknown value ..." error
message. However, while doing this, the actual length of the broken
sequence is not set, moreover with the variable expected to carry the
length being used meanwhile for temporary storing the last byte value.
As a result, the "Poll received unknown value ..." messages provide
incorrect sequence lengths if different from 1 byte.

While this bug doesn't affect Heyu ability to recognise and interpret
the spool file contents correctly, it makes it harder to diagnose other
problems, either hardware related or caused by other bugs, which
exhibit themselves with "Poll received unknown value ..." reports. This
issue has just been discovered while hunting for such other bugs (see
ticket #10).

Signed-off-by: Janusz Krzysztofik <jkrzyszt@tis.icnet.pl>
---
 poll.c |    1 +
 1 files changed, 1 insertions(+), 0 deletions(-)

diff --git a/poll.c b/poll.c
index 953c0a0..b47a40c 100644
--- a/poll.c
+++ b/poll.c
@@ -575,6 +575,7 @@ int check4poll( int showdata, int timeout )
 	    for(i = 0; i < wasflag;i++)
 		buf[i] = 0xff;
 	    buf[i] = n;
+	    n = wasflag + 1;
 	    wasflag = 0;
 	}
 	    
-- 
1.7.3.4

